@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Savkopio de la datumbazo en SQLite kaj restaŭro',
-	'dump_slogan' => 'Savkopio kaj restaŭro de la datumbazo SPIP'
-);
+	'dump_slogan' => 'Savkopio kaj restaŭro de la datumbazo SPIP',
+];
