@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'aucun_message_forum' => 'Kemenadenn forom ebet',
@@ -175,5 +171,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'tout_voir' => 'Gwelet an holl gemenadennoù',
 
 	// V
-	'voir_messages_objet' => 'Gwelet ar c’hemenadennoù'
-);
+	'voir_messages_objet' => 'Gwelet ar c’hemenadennoù',
+];
