@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'aucun_message_forum' => 'Neniu foruma mesaĝo',
@@ -180,5 +176,5 @@ La publikaj forumoj estos laŭkaze unu post la alia permesitaj
 	'tout_voir' => 'Vidi ĉiujn mesaĝojn',
 
 	// V
-	'voir_messages_objet' => 'vidi la mesaĝojn'
-);
+	'voir_messages_objet' => 'vidi la mesaĝojn',
+];
