@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -723,13 +722,13 @@ function plugin_message_incompatibilite($intervalle, $version, $nom, $balise) {
 
 		if (strlen($minimum)) {
 			if ($minimum_inclus and spip_version_compare($version, $minimum, '<')) {
-				return _T("plugin_${balise}_${type}", [
+				return _T("plugin_{$balise}_{$type}", [
 					'plugin' => $nom,
 					'version' => ' &ge; ' . $minimum
 				]);
 			}
 			if (!$minimum_inclus and spip_version_compare($version, $minimum, '<=')) {
-				return _T("plugin_${balise}_${type}", [
+				return _T("plugin_{$balise}_{$type}", [
 					'plugin' => $nom,
 					'version' => ' &gt; ' . $minimum
 				]);
@@ -738,13 +737,13 @@ function plugin_message_incompatibilite($intervalle, $version, $nom, $balise) {
 
 		if (strlen($maximum)) {
 			if ($maximum_inclus and spip_version_compare($version, $maximum, '>')) {
-				return _T("plugin_${balise}_${type}", [
+				return _T("plugin_{$balise}_{$type}", [
 					'plugin' => $nom,
 					'version' => ' &le; ' . $maximum
 				]);
 			}
 			if (!$maximum_inclus and spip_version_compare($version, $maximum, '>=')) {
-				return _T("plugin_${balise}_plugin", [
+				return _T("plugin_{$balise}_plugin", [
 					'plugin' => $nom,
 					'version' => ' &lt; ' . $maximum
 				]);
@@ -755,7 +754,7 @@ function plugin_message_incompatibilite($intervalle, $version, $nom, $balise) {
 	// note : il ne peut pas y avoir d'erreur sur
 	// - un 'utilise' sans version.
 	// - un 'php' sans version.
-	return _T("plugin_necessite_${type}_sans_version", ['plugin' => $nom]);
+	return _T("plugin_necessite_{$type}_sans_version", ['plugin' => $nom]);
 }
 
 
@@ -765,7 +764,7 @@ function plugin_controler_lib($lib, $url) {
 		include_spip('inc/charger_plugin');
 		$url = '<br />'	. bouton_telechargement_plugin($url, 'lib');
 	}*/
-	return _T('plugin_necessite_lib', ['lib' => $lib]) . " <a href='$url'>$url</a>";
+	return _T('plugin_necessite_lib', ['lib' => $lib]) . " <a href='" . attribut_url($url) . "'>$url</a>";
 }
 
 
@@ -864,7 +863,7 @@ function ecrire_plugin_actifs($plugin, $pipe_recherche = false, $operation = 'ra
 	$err = $msg = $header = [];
 	foreach ($plugin_valides as $p => $resume) {
 		// Les headers ne doivent pas indiquer les versions des extensions PHP, ni la version PHP
-		if (0 !== strpos($p, 'PHP:') and $p !== 'PHP') {
+		if (!str_starts_with($p, 'PHP:') and $p !== 'PHP') {
 			$header[] = $p . ($resume['version'] ? '(' . $resume['version'] . ')' : '');
 		}
 		if ($resume['dir']) {
@@ -953,7 +952,7 @@ function plugins_precompile_chemin($plugin_valides, $ordre) {
 			$prefix = strtoupper(preg_replace(',\W,', '_', $info['prefix']));
 			if (
 				$prefix !== 'SPIP'
-				and strpos($dir, ':') === false // exclure le cas des procure:
+				and !str_contains($dir, ':') // exclure le cas des procure:
 			) {
 				$contenu .= "define('_DIR_PLUGIN_$prefix',$dir);\n";
 				if (!$info['chemin']) {
@@ -1045,7 +1044,7 @@ function plugins_precompile_xxxtions($plugin_valides, $ordre) {
 				if (
 					!isset($info[$charge])
 					and $dir // exclure le cas du plugin "SPIP"
-					and strpos($dir, ':') === false // exclure le cas des procure:
+					and !str_contains($dir, ':') // exclure le cas des procure:
 					and file_exists("$dir$plug/paquet.xml") // uniquement pour les paquet.xml
 				) {
 					if (is_readable("$dir$plug/" . ($file = $info['prefix'] . '_' . $charge . '.php'))) {
