@@ -533,7 +533,7 @@ aŭ kontaktu vian retgastiganton.</span>',
 	'login_retoursitepublic' => 'reen al la publika spaco',
 	'login_sans_cookie' => 'Ensaluto sen kuketo',
 	'login_securise' => 'Sekura salutnomo',
-	'login_sinscrire' => 'registriĝi',
+	'login_sinscrire' => 'registriĝi', # MODIF
 	'login_test_navigateur' => 'testo retumilo/rekonektiĝo',
 	'login_verifiez_navigateur' => '(Kontrolu tamen ke via retumilo ne memoras pri via pasvorto...)',
 
@@ -625,6 +625,7 @@ kaj ensaluti.
 	'taille_ko' => '@taille@ kb',
 	'taille_mo' => '@taille@ Mb',
 	'taille_octets' => '@taille@ bitokoj',
+	'taille_octets_bi' => '@taille@ bitokoj',
 	'texte_actualite_site_1' => 'Kiam vi estos kutimiĝinta kun la interfaco, vi povos musklaki sur « ',
 	'texte_actualite_site_2' => 'kompleta interfaco',
 	'texte_actualite_site_3' => ' » por malfermi pliajn eblecojn.',
