@@ -500,7 +500,7 @@ serwisie "@nom_site_spip@" (@adresse_login@):',
 	'login_retour_public' => 'Powrót do strony publicznej',
 	'login_retour_site' => 'Powrót do strony publicznej',
 	'login_retoursitepublic' => 'Powrót do strony publicznej',
-	'login_sinscrire' => 'rejestracja',
+	'login_sinscrire' => 'rejestracja', # MODIF
 	'login_test_navigateur' => 'test przeglądarki/łącz ponownie',
 	'login_verifiez_navigateur' => '(Sprawdź czy Twoja przeglądarka nie zapamiętała hasła...)',
 
@@ -586,6 +586,7 @@ można ponownie połączyć się ze stroną.
 	'taille_ko' => '@taille@ kb',
 	'taille_mo' => '@taille@ Mb',
 	'taille_octets' => '@taille@ bytes',
+	'taille_octets_bi' => '@taille@ bytes',
 	'texte_actualite_site_1' => 'Kiedy poznasz interfejs, kliknij na «',
 	'texte_actualite_site_2' => 'kompletny interfejs',
 	'texte_actualite_site_3' => '» aby uruchomić więcej możliwości.',
